package com.qmth.themis.exam.api;

import java.util.HashMap;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.themis.business.bean.exam.LivenessVerifyBean;
import com.qmth.themis.business.enums.MqEnum;
import com.qmth.themis.business.service.TOeLivenessVerifyHistoryService;
import com.qmth.themis.common.util.Result;
import com.qmth.themis.common.util.ResultUtil;
import com.qmth.themis.mq.dto.MqDto;
import com.qmth.themis.mq.enums.MqTagEnum;
import com.qmth.themis.mq.enums.MqTopicEnum;
import com.qmth.themis.mq.service.MqDtoService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

/**
 * 活体验证
 * 
 * @Description:
 * @Author: xiatian
 * @Date: 2020-08-03
 */
@Api(tags = "活体验证")
@RestController
@RequestMapping("/${prefix.url.exam}/liveness")
public class TELivenessController {

	@Resource
	TOeLivenessVerifyHistoryService livenessVerifyHistoryService;

	@Resource
	MqDtoService mqDtoService;

	@ApiOperation(value = "活体验证结果")
	@RequestMapping(value = "/verify", method = RequestMethod.POST)
	@ApiResponses({ @ApiResponse(code = 200, message = "活体验证信息") })
	@Transactional
	public Result verify(@ApiParam(value = "考试记录ID", required = true) @RequestParam Long recordId,
			@ApiParam(value = "FIRST_START: 首次开考 RESUME_START: 断点恢复 IN_PROCESS: 过程中 WARNING_AUTO: 预警自动加入 INVIGILATE_MANUAL: 监考手工加入", required = true) @RequestParam String type,
			@ApiParam(value = "动作详情", required = true) @RequestParam String actions,
			@ApiParam(value = "整体第几次重试", required = true) @RequestParam Integer retry,
			@ApiParam(value = "验证开始时间", required = true) @RequestParam Long startTime,
			@ApiParam(value = "验证结束时间", required = true) @RequestParam Long finishTime,
			@ApiParam(value = "本地验证是否通过", required = true) @RequestParam Boolean pass) {
		LivenessVerifyBean ret = livenessVerifyHistoryService.verify(recordId, type, actions, retry, startTime,
				finishTime, pass);
		Map<String, Object> transMap = new HashMap<String, Object>();
		transMap.put("id", ret.getId());
		transMap.put("recordId", recordId);
		transMap.put("type", type);
		transMap.put("actions", actions);
		transMap.put("retry", retry);
		transMap.put("startTime", startTime);
		transMap.put("finishTime", finishTime);
		transMap.put("pass", pass);
		// mq发送消息start
		MqDto mqDto = new MqDto(MqTopicEnum.themisTopic.getCode(), MqTagEnum.livenessVerifySave.name(), transMap,
				MqEnum.EXAM, null, null);
		mqDtoService.assembleSendOneWayMsg(mqDto);
		return ResultUtil.ok(ret);
	}

}
